summaryrefslogtreecommitdiffstats
path: root/src/usr/hwpf/hwp/dram_training
diff options
context:
space:
mode:
authorRichard J. Knight <rjknight@us.ibm.com>2014-10-01 11:46:56 -0500
committerA. Patrick Williams III <iawillia@us.ibm.com>2014-11-12 13:39:46 -0600
commit6313118b632d0f985d9595dfad54e942a6ed02cf (patch)
tree93a3ed691347cd40cdf05b253734ecec9e03cee0 /src/usr/hwpf/hwp/dram_training
parent133ff602765190b62c16680e15f4d93d803597b6 (diff)
downloadtalos-hostboot-6313118b632d0f985d9595dfad54e942a6ed02cf.tar.gz
talos-hostboot-6313118b632d0f985d9595dfad54e942a6ed02cf.zip
SW279708: INITPROC: adjust DMI/ABUS CU PLL refclock switching for DCCAL operatio
Change-Id: If34822b3ac36579f110528682cf6c67eac9e8e6e CQ:SW279708 Reviewed-on: http://gfw160.aus.stglabs.ibm.com:8080/gerrit/13594 Reviewed-by: Thi N. Tran <thi@us.ibm.com> Tested-by: Thi N. Tran <thi@us.ibm.com> Reviewed-on: http://gfw160.aus.stglabs.ibm.com:8080/gerrit/13709 Reviewed-by: Richard J. Knight <rjknight@us.ibm.com> Tested-by: Jenkins Server Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com>
Diffstat (limited to 'src/usr/hwpf/hwp/dram_training')
-rw-r--r--src/usr/hwpf/hwp/dram_training/mem_pll_setup/cen_mem_pll_initf.C20
-rw-r--r--src/usr/hwpf/hwp/dram_training/mem_pll_setup/memb_pll_ring_attributes.xml56
2 files changed, 22 insertions, 54 deletions
diff --git a/src/usr/hwpf/hwp/dram_training/mem_pll_setup/memb_pll_ring_attributes.xml b/src/usr/hwpf/hwp/dram_training/mem_pll_setup/memb_pll_ring_attributes.xml
index b78596dea..ce85d83b4 100644
--- a/src/usr/hwpf/hwp/dram_training/mem_pll_setup/memb_pll_ring_attributes.xml
+++ b/src/usr/hwpf/hwp/dram_training/mem_pll_setup/memb_pll_ring_attributes.xml
@@ -5,7 +5,9 @@
<!-- -->
<!-- OpenPOWER HostBoot Project -->
<!-- -->
-<!-- COPYRIGHT International Business Machines Corp. 2013,2014 -->
+<!-- Contributors Listed Below - COPYRIGHT 2013,2014 -->
+<!-- [+] International Business Machines Corp. -->
+<!-- -->
<!-- -->
<!-- Licensed under the Apache License, Version 2.0 (the "License"); -->
<!-- you may not use this file except in compliance with the License. -->
@@ -22,7 +24,7 @@
<!-- IBM_PROLOG_END_TAG -->
<attributes>
<!-- ********************************************************************* -->
- <!-- $Id: memb_pll_ring_attributes.xml,v 1.12 2014/01/14 16:13:30 jmcgill Exp $ -->
+ <!-- $Id: memb_pll_ring_attributes.xml,v 1.13 2014/09/23 21:55:16 jmcgill Exp $ -->
<attribute>
<id>ATTR_MEMB_TP_BNDY_PLL_DATA</id>
<targetType>TARGET_TYPE_MEMBUF_CHIP</targetType>
@@ -74,31 +76,6 @@
</attribute>
<!-- ********************************************************************* -->
<attribute>
- <id>ATTR_MEMB_TP_BNDY_PLL_FOR_DCCAL_DATA</id>
- <targetType>TARGET_TYPE_MEMBUF_CHIP</targetType>
- <description>Ring image for Centaur tp_bndy_pll ring
- creator: platform
- firmware notes:
- </description>
- <valueType>uint8</valueType>
- <array>80</array>
- <platInit/>
- <persistRuntime/>
- </attribute>
- <!-- ********************************************************************* -->
- <attribute>
- <id>ATTR_MEMB_TP_BNDY_PLL_FOR_DCCAL_LENGTH</id>
- <targetType>TARGET_TYPE_MEMBUF_CHIP</targetType>
- <description>Length of data in ring image for Centaur tp_bndy_pll ring
- creator: platform
- firmware notes:
- </description>
- <valueType>uint32</valueType>
- <platInit/>
- <persistRuntime/>
- </attribute>
- <!-- ********************************************************************* -->
- <attribute>
<id>ATTR_MEMB_TP_BNDY_PLL_NEST4000_MEM1066_DATA</id>
<targetType>TARGET_TYPE_MEMBUF_CHIP</targetType>
<description>Ring image for Centaur tp_bndy_pll ring for nest=4000 mem=1066
@@ -299,31 +276,6 @@
</attribute>
<!-- ********************************************************************* -->
<attribute>
- <id>ATTR_MEMB_TP_BNDY_PLL_FOR_RUNTIME_DATA</id>
- <targetType>TARGET_TYPE_MEMBUF_CHIP</targetType>
- <description>Ring image for Centaur tp_bndy_pll ring for run time and pll cleanup
- creator: platform
- firmware notes:
- </description>
- <valueType>uint8</valueType>
- <array>80</array>
- <platInit/>
- <persistRuntime/>
- </attribute>
- <!-- ********************************************************************* -->
- <attribute>
- <id>ATTR_MEMB_TP_BNDY_PLL_FOR_RUNTIME_LENGTH</id>
- <targetType>TARGET_TYPE_MEMBUF_CHIP</targetType>
- <description>Length of data in ring image for Centaur tp_bndy_pll ring
- creator: platform
- firmware notes:
- </description>
- <valueType>uint32</valueType>
- <platInit/>
- <persistRuntime/>
- </attribute>
- <!-- ********************************************************************* -->
- <attribute>
<id>ATTR_MEMB_DMI_CUPLL_PFD360_OFFSET</id>
<targetType>TARGET_TYPE_MEMBUF_CHIP</targetType>
<description>Scan chain position of CU PLL PDF360 bit in tp_pll_bndy chain (Offset from beginning of chain)
OpenPOWER on IntegriCloud
diff --git a/src/usr/hwpf/hwp/dram_training/mem_pll_setup/cen_mem_pll_initf.C b/src/usr/hwpf/hwp/dram_training/mem_pll_setup/cen_mem_pll_initf.C
index 64d7fe1e7..728a83c28 100644
--- a/src/usr/hwpf/hwp/dram_training/mem_pll_setup/cen_mem_pll_initf.C
+++ b/src/usr/hwpf/hwp/dram_training/mem_pll_setup/cen_mem_pll_initf.C
@@ -22,7 +22,7 @@
/* permissions and limitations under the License. */
/* */
/* IBM_PROLOG_END_TAG */
-// $Id: cen_mem_pll_initf.C,v 1.12 2014/02/04 21:08:46 mfred Exp $
+// $Id: cen_mem_pll_initf.C,v 1.13 2014/09/23 21:53:45 jmcgill Exp $
// $Source: /afs/awd/projects/eclipz/KnowledgeBase/.cvsroot/eclipz/chips/centaur/working/procedures/ipl/fapi/cen_mem_pll_initf.C,v $
//------------------------------------------------------------------------------
// *! (C) Copyright International Business Machines Corp. 2012
@@ -478,6 +478,16 @@ fapi::ReturnCode cen_mem_pll_initf(const fapi::Target & i_target)
break;
}
+ // set DMI PFD360 bit for runtime
+ uint32_t memb_dmi_cupll_pfd360_bit_offset;
+ rc = FAPI_ATTR_GET(ATTR_MEMB_DMI_CUPLL_PFD360_OFFSET, &i_target, memb_dmi_cupll_pfd360_bit_offset);
+ if (rc)
+ {
+ FAPI_ERR("Failed to get DMI PFD360 offset attribute");
+ break;
+ }
+ FAPI_DBG("DMI PLL PFD360 offset is set to : %d.", memb_dmi_cupll_pfd360_bit_offset);
+
rc = FAPI_ATTR_GET(ATTR_MEMB_MEM_PLL_CFG_UPDATE_OFFSET, &i_target, mem_pll_update_bit_offset);
if (rc)
{
@@ -503,7 +513,10 @@ fapi::ReturnCode cen_mem_pll_initf(const fapi::Target & i_target)
// Put the ring data from the attribute into the buffer
rc_ecmd |= ring_data.insert(attrRingData, 0, ring_length, 0);
- // force desired value of PLLCTR1(44)
+ // clamp PFD360 bit to 0 for runtime
+ rc_ecmd |= ring_data.clearBit(memb_dmi_cupll_pfd360_bit_offset);
+
+ // force desired value of MEM PLLCTR1(44)
if (scan_num % 2) {
rc_ecmd |= ring_data.setBit(mem_pll_update_bit_offset);
}
@@ -544,6 +557,9 @@ fapi::ReturnCode cen_mem_pll_initf(const fapi::Target & i_target)
This section is automatically updated by CVS when you check in this file.
Be sure to create CVS comments when you commit so that they can be included here.
$Log: cen_mem_pll_initf.C,v $
+Revision 1.13 2014/09/23 21:53:45 jmcgill
+add explicit clear for DMI PFD360 bit, based on change in base attribute values (SW279708)
+
Revision 1.12 2014/02/04 21:08:46 mfred
Change to leave TP FIR bit 3 masked out. SW245030.